@@ -39,7 +39,7 @@ def compute_args():
         formatter_class=CustomHelpFormatter,
     )
     my_parser.add_argument(
-        "-n",
+        "-g",
         "--games",
         metavar="X",
         action="store",
@@ -53,7 +53,13 @@ def compute_args():
         "--rules",
         action="store_true",
         help="display rules of reversi",
-    ),    
+    ),
+    my_parser.add_argument(
+        "-n",
+        "--nocolor",
+        action="store_true",
+        help="no color : use if unicode or color problems",
+    ),          
     my_parser.add_argument(
         "-b",
         "--blackbot",
